/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.kintai.dao;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import com.google.appengine.api.datastore.Query;

import jp.cloudzero.mosp.exception.CloudzeroUnsupportedException;
import jp.getset.gae.bigtable.PreparedOption;
import jp.getset.gae.bigtable.PreparedStatement;
import jp.getset.gae.bigtable.Statement.Mode;
import jp.getset.gae.bigtable.option.PreparedProperty;
import jp.mosp.common.common.BaseDao;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.kintai.common.dao.MKihonDao;
import jp.mosp.kintai.dto.MSyukkinboDto;

/**
 * M_SYUKKINBO(oΕ)DAONX B
 */
public class MSyukkinboDao extends BaseDao {
	
	// e[uyуL[
	/**
	 * M_SYUKKINBO(oΕ)B
	 */
	public static final String	TABLE			= "M_SYUKKINBO";
	
	/**
	 * KEY_1 = KCODE(ЈR[h)B
	 */
	public static final String	KEY_1			= "KCODE";
	/**
	 * KEY_2 = HIZUKE(t)B
	 */
	public static final String	KEY_2			= "HIZUKE";
	
	// 
	/**
	 * KCODE(ЈR[h)B
	 */
	public static final String	COL_KCODE		= "KCODE";
	/**
	 * HIZUKE(t)B
	 */
	public static final String	COL_HIZUKE		= "HIZUKE";
	/**
	 * NEN(N)B
	 */
	public static final String	COL_NEN			= "NEN";
	/**
	 * TUKI()B
	 */
	public static final String	COL_TUKI		= "TUKI";
	/**
	 * HI()B
	 */
	public static final String	COL_HI			= "HI";
	/**
	 * SYOZOKU(R[h)B
	 */
	public static final String	COL_SYOZOKU		= "SYOZOKU";
	/**
	 * NINSYO(F؎)B
	 */
	public static final String	COL_NINSYO		= "NINSYO";
	/**
	 * SYJIKOKU(oΎ)B
	 */
	public static final String	COL_SYJIKOKU	= "SYJIKOKU";
	/**
	 * KINMU(Ζ`)B
	 */
	public static final String	COL_KINMU		= "KINMU";
	/**
	 * SHANKYUKB(oΔx敪)B
	 */
	public static final String	COL_SHANKYUKB	= "SHANKYUKB";
	/**
	 * KYUSYUKB(xo敪)B
	 */
	public static final String	COL_KYUSYUKB	= "KYUSYUKB";
	/**
	 * TIRIYUU(xR)B
	 */
	public static final String	COL_TIRIYUU		= "TIRIYUU";
	/**
	 * TICOMENT(xRg)B
	 */
	public static final String	COL_TICOMENT	= "TICOMENT";
	/**
	 * TISYOUMEI(xؖ)B
	 */
	public static final String	COL_TISYOUMEI	= "TISYOUMEI";
	/**
	 * TIJIKAN(x)B
	 */
	public static final String	COL_TIJIKAN		= "TIJIKAN";
	/**
	 * SYTIMES(oΓ͓)B
	 */
	public static final String	COL_SYTIMES		= "SYTIMES";
	/**
	 * TAJIKOKU(ގЎ)B
	 */
	public static final String	COL_TAJIKOKU	= "TAJIKOKU";
	/**
	 * KINMUJI(Ζ)B
	 */
	public static final String	COL_KINMUJI		= "KINMUJI";
	/**
	 * KYUKEIJI(xe)B
	 */
	public static final String	COL_KYUKEIJI	= "KYUKEIJI";
	/**
	 * THANKYUKB(ދΔx敪)B
	 */
	public static final String	COL_THANKYUKB	= "THANKYUKB";
	/**
	 * SORIYUU(ޗR)B
	 */
	public static final String	COL_SORIYUU		= "SORIYUU";
	/**
	 * SOCOMENT(ރRg)B
	 */
	public static final String	COL_SOCOMENT	= "SOCOMENT";
	/**
	 * SOSYOUMEI(ޏؖ)B
	 */
	public static final String	COL_SOSYOUMEI	= "SOSYOUMEI";
	/**
	 * SOJIKAN(ގ)B
	 */
	public static final String	COL_SOJIKAN		= "SOJIKAN";
	/**
	 * ZAJIKAN(cƎ)B
	 */
	public static final String	COL_ZAJIKAN		= "ZAJIKAN";
	/**
	 * KSJIKAN(xo)B
	 */
	public static final String	COL_KSJIKAN		= "KSJIKAN";
	/**
	 * SNJIKAN([鎞)B
	 */
	public static final String	COL_SNJIKAN		= "SNJIKAN";
	/**
	 * SYOKUJI(H蓖x)B
	 */
	public static final String	COL_SYOKUJI		= "SYOKUJI";
	/**
	 * CYOKU1(1蓖x)B
	 */
	public static final String	COL_CYOKU1		= "CYOKU1";
	/**
	 * CYOKU2(2蓖x)B
	 */
	public static final String	COL_CYOKU2		= "CYOKU2";
	/**
	 * CYOKU3(3蓖x)B
	 */
	public static final String	COL_CYOKU3		= "CYOKU3";
	/**
	 * HOKA1(̑x1)B
	 */
	public static final String	COL_HOKA1		= "HOKA1";
	/**
	 * HOKA2(̑x2)B
	 */
	public static final String	COL_HOKA2		= "HOKA2";
	/**
	 * HOKA3(̑x3)B
	 */
	public static final String	COL_HOKA3		= "HOKA3";
	/**
	 * HOKA4(̑x4)B
	 */
	public static final String	COL_HOKA4		= "HOKA4";
	/**
	 * HOKA5(̑x5)B
	 */
	public static final String	COL_HOKA5		= "HOKA5";
	/**
	 * TATIMES(ގГ͓)B
	 */
	public static final String	COL_TATIMES		= "TATIMES";
	/**
	 * KKRIYUU(xɗR)B
	 */
	public static final String	COL_KKRIYUU		= "KKRIYUU";
	/**
	 * DAIKYUJYU(x[)B
	 */
	public static final String	COL_DAIKYUJYU	= "DAIKYUJYU";
	/**
	 * KKCOMENT(xɃRg)B
	 */
	public static final String	COL_KKCOMENT	= "KKCOMENT";
	/**
	 * KKSYOUMEI(xɏؖ)B
	 */
	public static final String	COL_KKSYOUMEI	= "KKSYOUMEI";
	/**
	 * KKJIKAN(xɎ)B
	 */
	public static final String	COL_KKJIKAN		= "KKJIKAN";
	/**
	 * KKTIMES(xɓ͓)B
	 */
	public static final String	COL_KKTIMES		= "KKTIMES";
	/**
	 * SNRIYUU(FR)B
	 */
	public static final String	COL_SNRIYUU		= "SNRIYUU";
	/**
	 * SNCOMENT(FRg)B
	 */
	public static final String	COL_SNCOMENT	= "SNCOMENT";
	/**
	 * SNTIMES(F͓)B
	 */
	public static final String	COL_SNTIMES		= "SNTIMES";
	/**
	 * UPDTTIMES(XV)B
	 */
	public static final String	COL_UPDTTIMES	= "UPDTTIMES";
	/**
	 * NIJIKYU(񎞊ԔNx)B
	 */
	public static final String	COL_NIJIKYU		= "NIJIKYU";
	/**
	 * WARIMASI1(1.00)B
	 */
	public static final String	COL_WARIMASI1	= "WARIMASI1";
	/**
	 * ZKINMU(OΖ`)B
	 */
	public static final String	COL_ZKINMU		= "ZKINMU";
	

	/**
	 * RXgN^
	 */
	public MSyukkinboDao() {
		super();
	}
	
	/**
	 * ʎ擾(DTOList)
	 * @return List Xg
	 * @throws SQLException SQLOꍇ
	 */
	private List<MSyukkinboDto> mappingAll() throws SQLException {
		List<MSyukkinboDto> all = new ArrayList<MSyukkinboDto>();
		while (rs.next()) {
			all.add(mapping());
		}
		return all;
	}
	
	/**
	 * ʎ擾(DTO)
	 * @return m_syukkinboDto m_syukkinboR[h
	 * @throws SQLException SQLOꍇ
	 */
	private MSyukkinboDto mapping() throws SQLException {
		MSyukkinboDto dto = new MSyukkinboDto();
		dto.setKCode(rs.getString(COL_KCODE)); //ЈR[h
		dto.setHizuke(rs.getString(COL_HIZUKE)); //t
		dto.setNen(rs.getInt(COL_NEN)); //N
		dto.setTuki(rs.getInt(COL_TUKI)); //
		dto.setHi(rs.getInt(COL_HI)); //
		dto.setSyozoku(rs.getString(COL_SYOZOKU)); //R[h
		dto.setNinsyo(rs.getString(COL_NINSYO)); //F؎
		dto.setSyJikoku(rs.getString(COL_SYJIKOKU)); //oΎ
		dto.setKinmu(rs.getString(COL_KINMU)); //Ζ`
		dto.setSHankyuKb(rs.getString(COL_SHANKYUKB)); //x敪
		dto.setKyusyuKb(rs.getString(COL_KYUSYUKB)); //xo敪
		dto.setTiRiyuu(rs.getString(COL_TIRIYUU)); //xR
		dto.setTiComent(rs.getString(COL_TICOMENT)); //xRg
		dto.setTiSyoumei(rs.getString(COL_TISYOUMEI)); //xؖ
		dto.setTiJikan(rs.getInt(COL_TIJIKAN)); //x
		dto.setSyTimes(rs.getString(COL_SYTIMES)); //oΓ͓
		dto.setTaJikoku(rs.getString(COL_TAJIKOKU)); //ގЎ
		dto.setKinmuJi(rs.getInt(COL_KINMUJI)); //Ζ
		dto.setKyukeiJi(rs.getInt(COL_KYUKEIJI)); //xe
		dto.setTHankyuKb(rs.getString(COL_THANKYUKB)); //x敪
		dto.setSoRiyuu(rs.getString(COL_SORIYUU)); //ޗR
		dto.setSoComent(rs.getString(COL_SOCOMENT)); //ރRg
		dto.setSoSyoumei(rs.getString(COL_SOSYOUMEI)); //ޏؖ
		dto.setSoJikan(rs.getInt(COL_SOJIKAN)); //ގ
		dto.setZaJikan(rs.getInt(COL_ZAJIKAN)); //cƎ
		dto.setKsJikan(rs.getInt(COL_KSJIKAN)); //xo
		dto.setSnJikan(rs.getInt(COL_SNJIKAN)); //[鎞
		dto.setSyokuji(rs.getInt(COL_SYOKUJI)); //H蓖x
		dto.setCyoku1(rs.getInt(COL_CYOKU1)); //1蓖x
		dto.setCyoku2(rs.getInt(COL_CYOKU2)); //2蓖x
		dto.setCyoku3(rs.getInt(COL_CYOKU3)); //3蓖x
		dto.setHoka1(rs.getInt(COL_HOKA1)); //̑x1
		dto.setHoka2(rs.getInt(COL_HOKA2)); //̑x2
		dto.setHoka3(rs.getInt(COL_HOKA3)); //̑x3
		dto.setHoka4(rs.getInt(COL_HOKA4)); //̑x4
		dto.setHoka5(rs.getInt(COL_HOKA5)); //̑x5
		dto.setTaTimes(rs.getString(COL_TATIMES)); //ގГ͓
		dto.setKKRiyuu(rs.getString(COL_KKRIYUU)); //xɗR
		dto.setDaiKyuJyu(rs.getString(COL_DAIKYUJYU)); //x[
		dto.setKKComent(rs.getString(COL_KKCOMENT)); //xɃRg
		dto.setKKSyoumei(rs.getString(COL_KKSYOUMEI)); //xɏؖ
		dto.setKKJikan(rs.getInt(COL_KKJIKAN)); //xɎ
		dto.setKKTimes(rs.getString(COL_KKTIMES)); //xɓ͓
		dto.setSnRiyuu(rs.getString(COL_SNRIYUU)); //FR
		dto.setSnComent(rs.getString(COL_SNCOMENT)); //FRg
		dto.setSnTimes(rs.getString(COL_SNTIMES)); //F͓
		dto.setUpdtTimes(rs.getString(COL_UPDTTIMES)); //XV
		dto.setNijiKyu(rs.getInt(COL_NIJIKYU)); //񎞊ԔNx
		dto.setWarimasi1(rs.getInt(COL_WARIMASI1)); //1.00
		dto.setZKinmu(rs.getString(COL_ZKINMU)); //OΖ`
		return dto;
	}
	
	/**
	 * Sf[^擾
	 * @return List (DTOList)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public List<?> findAll() throws SQLException, IllegalAccessException, NoSuchFieldException {
		try {
			prepareStatement(getSelectQuery(getClass()) + getOrderForKey(getClass()));
			executeQuery();
			List<?> all = mappingAll();
			return all;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * L[ɂf[^擾
	 * @param kcode ЈR[h(L[)
	 * @param hizuke t(L[)
	 * @return m_syukkinboDto (DTO)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public MSyukkinboDto findForKey(String kcode, String hizuke) throws SQLException, IllegalAccessException,
			NoSuchFieldException {
		try {
			index = 1;
			prepareStatement(getSelectQuery(getClass()) + getConditionForKey(getClass()));
			setParam(index++, kcode);
			setParam(index++, hizuke);
			executeQuery();
			MSyukkinboDto dto = null;
			if (rs.next()) {
				dto = mapping();
				mappingCommonInfo(dto);
			}
			return dto;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * L[ɂsbN擾
	 * @param kcode ЈR[h(L[)
	 * @param hizuke t(L[)
	 * @return m_syukkinboDto (DTO)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public MSyukkinboDto findForUpdate(String kcode, String hizuke) throws SQLException, IllegalAccessException,
			NoSuchFieldException {
		try {
			index = 1;
			prepareStatement(getSelectQuery(getClass()) + getConditionForKey(getClass()) + getForUpdate());
			setParam(index++, kcode);
			setParam(index++, hizuke);
			executeQuery();
			MSyukkinboDto dto = null;
			if (rs.next()) {
				dto = mapping();
				mappingCommonInfo(dto);
			}
			return dto;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾
	 * @param kcode ЈR[h
	 * @param hizuke t
	 * @return List (DTOList)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public List<MSyukkinboDto> findForCondition(String kcode, String hizuke) throws SQLException,
			IllegalAccessException, NoSuchFieldException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_KCODE);
		sb.append(" = ? AND ");
		sb.append(COL_HIZUKE);
		sb.append(" = ? ");
		this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
		this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.EQUAL);
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString() + getOrderForKey(getClass()));
			setParam(index++, kcode);
			setParam(index++, hizuke + "%");
			executeQuery();
			List<MSyukkinboDto> list = mappingAll();
			return list;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾
	 * @param kcode 		ЈR[h
	 * @param startDate 	Jnt
	 * @param endDate 		It
	 * @return List (DTOList)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public List<MSyukkinboDto> findForAttendanceList(String kcode, String startDate, String endDate)
			throws SQLException, IllegalAccessException, NoSuchFieldException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_KCODE);
		sb.append(" = ? AND ");
		sb.append(COL_HIZUKE);
		sb.append(" >= ? AND ");
		sb.append(COL_HIZUKE);
		sb.append(" <= ? ");
		this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
		this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.GREATER_THAN_OR_EQUAL);
		this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.LESS_THAN_OR_EQUAL);
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString() + getOrderForKey(getClass()));
			setParam(index++, kcode);
			setParam(index++, startDate);
			setParam(index++, endDate);
			executeQuery();
			List<MSyukkinboDto> list = mappingAll();
			return list;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾
	 * @param date		t
	 * @param kCode		ЈR[h
	 * @param kName		Ј
	 * @param approval	F
	 * @return m_syukkinboDto (DTO)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public MSyukkinboDto findForDayApproval(String date, String kCode, String kName, String approval)
			throws SQLException, IllegalAccessException, NoSuchFieldException {
		throw new CloudzeroUnsupportedException();
/*		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_HIZUKE);
		sb.append(" = ? ");
		if (!kCode.equals("")) {
			sb.append(" AND ");
			sb.append(COL_KCODE);
			sb.append(" = ? ");
		}
		if (!kName.equals("")) {
			sb.append(" AND ");
			sb.append(" ( ");
			sb.append(COL_KCODE + " IN (" + MKihonDao.getSearchKNameSubQuery() + ") ");
			sb.append(" ) ");
		}
		if (!approval.equals("")) {
			sb.append(" AND ");
			sb.append(COL_SNRIYUU);
			sb.append(" = ? ");
		}
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString() + getOrderForKey(getClass()));
			setParam(index++, date);
			if (!kCode.equals("")) {
				setParam(index++, kCode);
			}
			if (!kName.equals("")) {
				setParam(index++, "%" + kName + "%");
			}
			if (!approval.equals("")) {
				setParam(index++, approval);
			}
			executeQuery();
			MSyukkinboDto dto = null;
			if (rs.next()) {
				dto = mapping();
				mappingCommonInfo(dto);
			}
			return dto;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}*/
	}
	
	/**
	 * cƎԍvl擾
	 * @param kcode ЈR[h
	 * @param startdate Jnt
	 * @param enddate It
	 * @return v
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public int findForOverTimeSum(String kcode, String startdate, String enddate) throws SQLException,
			IllegalAccessException, NoSuchFieldException {
		try {
			int sumOverTime = 0;
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("SELECT SUM(");
			sb.append(COL_ZAJIKAN);
			sb.append(") FROM ");
			sb.append(TABLE);
			sb.append(" WHERE ");
			sb.append(COL_KCODE);
			sb.append(" = ?");
			sb.append(" AND ? <= ");
			sb.append(COL_HIZUKE);
			sb.append(" AND ");
			sb.append(COL_HIZUKE);
			sb.append(" <= ? ");
			
			this.setPreparedStatement(PreparedStatement.Mode.SELECT, getClass());
			this.pob.appendOperationSum(COL_ZAJIKAN);
			this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
			this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.GREATER_THAN_OR_EQUAL);
			this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.LESS_THAN_OR_EQUAL);
			prepareStatement(sb.toString());
			setParam(index++, kcode);
			setParam(index++, startdate);
			setParam(index++, enddate);
			executeQuery();
			if (rs.next()) {
//				sumOverTime = rs.getInt(1);
				sumOverTime = rs.getInt(COL_ZAJIKAN);
			}
			return sumOverTime;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * ɂf[^擾
	 * @param kcode 		ЈR[h
	 * @param startDate 	Jnt
	 * @param endDate 		It
	 * @param snriyuu ΏۏFR
	 * @return List (DTOList)
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 */
	public List<MSyukkinboDto> findForApprovalList(String kcode, String startDate, String endDate, String snriyuu)
			throws SQLException, IllegalAccessException, NoSuchFieldException {
		index = 1;
		StringBuffer sb = new StringBuffer();
		sb.append("WHERE ");
		sb.append(COL_KCODE);
		sb.append(" = ? ");
		sb.append(" AND ");
		sb.append(COL_HIZUKE);
		sb.append(" >= ? ");
		sb.append(" AND ");
		sb.append(COL_HIZUKE);
		sb.append(" <= ? ");
		this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
		this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.GREATER_THAN_OR_EQUAL);
		this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.LESS_THAN_OR_EQUAL);
		if (snriyuu.length() != 0) {
			sb.append(" AND ");
			sb.append(COL_SNRIYUU);
			sb.append(" = ? ");
			this.pob.appendWhere(COL_SNRIYUU, Query.FilterOperator.EQUAL);
		}
		try {
			prepareStatement(getSelectQuery(getClass()) + sb.toString() + getOrderForKey(getClass()));
			setParam(index++, kcode);
			setParam(index++, startDate);
			setParam(index++, endDate);
			if (snriyuu.length() != 0) {
				setParam(index++, snriyuu);
			}
			executeQuery();
			List<MSyukkinboDto> list = mappingAll();
			return list;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}
	 * @param dto }ΏDTO
	 * @return int }()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int insert(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			prepareStatement(getInsertQuery(getClass()));
			setParams(dto, true);
			executeUpdate();
			chkInsert(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}ioΓ́j
	 * @param dto }ΏDTO
	 * @return int }()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int insertStart(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("INSERT INTO ");
			sb.append(TABLE);
			sb.append(" (");
			sb.append(COL_KCODE + MospConst.DATA_SEPARATOR);
			sb.append(COL_HIZUKE + MospConst.DATA_SEPARATOR);
			sb.append(COL_NEN + MospConst.DATA_SEPARATOR);
			sb.append(COL_TUKI + MospConst.DATA_SEPARATOR);
			sb.append(COL_HI + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYOZOKU + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYJIKOKU + MospConst.DATA_SEPARATOR);
			sb.append(COL_KINMU + MospConst.DATA_SEPARATOR);
			sb.append(COL_SHANKYUKB + MospConst.DATA_SEPARATOR);
			sb.append(COL_KYUSYUKB + MospConst.DATA_SEPARATOR);
			sb.append(COL_TIRIYUU + MospConst.DATA_SEPARATOR);
			sb.append(COL_TICOMENT + MospConst.DATA_SEPARATOR);
			sb.append(COL_TISYOUMEI + MospConst.DATA_SEPARATOR);
			sb.append(COL_TIJIKAN + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYTIMES + MospConst.DATA_SEPARATOR);
			// ̔f
			sb.append(COL_SNRIYUU + MospConst.DATA_SEPARATOR);
			sb.append(INSERT_DATE + MospConst.DATA_SEPARATOR);
			sb.append(INSERT_USER + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_DATE + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_USER);
			sb.append(") VALUES(");
			for (int i = 0; i < 19; i++) {
				sb.append(" ?,");
			}
			sb.append(" ?)");
			
			// GAE
			String properties[] = {
					COL_KCODE,   COL_HIZUKE,   COL_NEN,       COL_TUKI,      COL_HI,
					COL_SYOZOKU, COL_SYJIKOKU, COL_KINMU,     COL_SHANKYUKB, COL_KYUSYUKB,
					COL_TIRIYUU, COL_TICOMENT, COL_TISYOUMEI, COL_TIJIKAN,   COL_SYTIMES,
					COL_SNRIYUU, INSERT_DATE,  INSERT_USER,   UPDATE_DATE,   UPDATE_USER
			};
			this.setPreparedStatementWithProperties(PreparedStatement.Mode.INSERT, properties);
			
			prepareStatement(sb.toString());
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			setParam(index++, dto.getNen());
			setParam(index++, dto.getTuki());
			setParam(index++, dto.getHi());
			setParam(index++, dto.getSyozoku());
			setParam(index++, dto.getSyJikoku());
			setParam(index++, dto.getKinmu());
			setParam(index++, dto.getSHankyuKb());
			setParam(index++, dto.getKyusyuKb());
			setParam(index++, dto.getTiRiyuu());
			setParam(index++, dto.getTiComent());
			setParam(index++, dto.getTiSyoumei());
			setParam(index++, dto.getTiJikan());
			setParam(index++, dto.getSyTimes());
			// ̔f
			setParam(index++, dto.getSnRiyuu());
			setCommonParams(true);
			executeUpdate();
			chkInsert(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}ixɓ́j
	 * @param dto }ΏDTO
	 * @return int }()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int insertHoliday(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("INSERT INTO ");
			sb.append(TABLE);
			sb.append(" (");
			sb.append(COL_KCODE + MospConst.DATA_SEPARATOR);
			sb.append(COL_HIZUKE + MospConst.DATA_SEPARATOR);
			sb.append(COL_NEN + MospConst.DATA_SEPARATOR);
			sb.append(COL_TUKI + MospConst.DATA_SEPARATOR);
			sb.append(COL_HI + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYOZOKU + MospConst.DATA_SEPARATOR);
			sb.append(COL_KINMU + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKRIYUU + MospConst.DATA_SEPARATOR);
			sb.append(COL_DAIKYUJYU + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKCOMENT + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKSYOUMEI + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKJIKAN + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKTIMES + MospConst.DATA_SEPARATOR);
			sb.append(COL_SNRIYUU + MospConst.DATA_SEPARATOR);
			sb.append(COL_UPDTTIMES + MospConst.DATA_SEPARATOR);
			sb.append(INSERT_DATE + MospConst.DATA_SEPARATOR);
			sb.append(INSERT_USER + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_DATE + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_USER);
			sb.append(") VALUES(");
			for (int i = 0; i < 18; i++) {
				sb.append(" ?,");
			}
			sb.append(" ?)");
			
			// GAE
			String properties[] = {
					COL_KCODE,     COL_HIZUKE,  COL_NEN,     COL_TUKI,      COL_HI,
					COL_SYOZOKU,   COL_KINMU,   COL_KKRIYUU, COL_DAIKYUJYU, COL_KKCOMENT,
					COL_KKSYOUMEI, COL_KKJIKAN, COL_KKTIMES, COL_SNRIYUU,   COL_UPDTTIMES,
					INSERT_DATE,   INSERT_USER, UPDATE_DATE, UPDATE_USER
			};
			this.setPreparedStatementWithProperties(PreparedStatement.Mode.INSERT, properties);

			prepareStatement(sb.toString());
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			setParam(index++, dto.getNen());
			setParam(index++, dto.getTuki());
			setParam(index++, dto.getHi());
			setParam(index++, dto.getSyozoku());
			setParam(index++, dto.getKinmu());
			setParam(index++, dto.getKKRiyuu());
			setParam(index++, dto.getDaiKyuJyu());
			setParam(index++, dto.getKKComent());
			setParam(index++, dto.getKKSyoumei());
			setParam(index++, dto.getKKJikan());
			setParam(index++, dto.getKKTimes());
			setParam(index++, dto.getSnRiyuu());
			setParam(index++, dto.getUpdtTimes());
			setCommonParams(true);
			executeUpdate();
			chkInsert(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^}
	 * @param 	aryDto }ΏDTO
	 * @return int }()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int insert(MSyukkinboDto[] aryDto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			prepareStatement(getInsertQuery(getClass(), aryDto.length, aryDto.length));
			for (MSyukkinboDto element : aryDto) {
				setParams(element, true);
			}
			executeUpdate();
			chkInsert(aryDto.length);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^XVioΓ́j
	 * @param dto XVΏDTO
	 * @return int XV()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int updateStart(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("UPDATE ");
			sb.append(TABLE);
			sb.append(" SET ");
			sb.append(COL_SYJIKOKU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KINMU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SHANKYUKB + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KYUSYUKB + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_TIRIYUU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_TICOMENT + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_TISYOUMEI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_TIJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYTIMES + " =?" + MospConst.DATA_SEPARATOR);
			// ̔f
			sb.append(COL_SNRIYUU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_DATE + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_USER + " =?");
			sb.append(" WHERE ");
			sb.append(COL_KCODE + " =?");
			sb.append(" AND ");
			sb.append(COL_HIZUKE + " =?");
			
			// GAE
			String properties[] = {
					COL_SYJIKOKU, COL_KINMU,     COL_SHANKYUKB, COL_KYUSYUKB, COL_TIRIYUU,
					COL_TICOMENT, COL_TISYOUMEI, COL_TIJIKAN,   COL_SYTIMES,  COL_SNRIYUU,
					UPDATE_DATE,  UPDATE_USER
			};
			this.setPreparedStatementWithProperties(PreparedStatement.Mode.UPDATE, properties);
			this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
			this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.EQUAL);
			
			prepareStatement(sb.toString());
			setParam(index++, dto.getSyJikoku());
			setParam(index++, dto.getKinmu());
			setParam(index++, dto.getSHankyuKb());
			setParam(index++, dto.getKyusyuKb());
			setParam(index++, dto.getTiRiyuu());
			setParam(index++, dto.getTiComent());
			setParam(index++, dto.getTiSyoumei());
			setParam(index++, dto.getTiJikan());
			setParam(index++, dto.getSyTimes());
			// ̔f
			setParam(index++, dto.getSnRiyuu());
			setCommonParams(false);
			// L[
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			executeUpdate();
			chkUpdate(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^XViދΓ́j
	 * @param dto XVΏDTO
	 * @return int XV()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int updateQuit(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("UPDATE ");
			sb.append(TABLE);
			sb.append(" SET ");
			sb.append(COL_TAJIKOKU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KINMUJI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KYUKEIJI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_THANKYUKB + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SORIYUU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SOCOMENT + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SOSYOUMEI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SOJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_ZAJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KSJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SNJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SYOKUJI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_CYOKU1 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_CYOKU2 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_CYOKU3 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_HOKA1 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_HOKA2 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_HOKA3 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_HOKA4 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_HOKA5 + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_TATIMES + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_SNRIYUU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_UPDTTIMES + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_DATE + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_USER + " =?");
			sb.append(" WHERE ");
			sb.append(COL_KCODE + " =?");
			sb.append(" AND ");
			sb.append(COL_HIZUKE + " =?");
			
			// GAE
			String properties[] = {
					COL_TAJIKOKU, COL_KINMUJI,   COL_KYUKEIJI,  COL_THANKYUKB, COL_SORIYUU,
					COL_SOCOMENT, COL_SOSYOUMEI, COL_SOJIKAN,   COL_ZAJIKAN,   COL_KSJIKAN,
					COL_SNJIKAN,  COL_SYOKUJI,   COL_CYOKU1,    COL_CYOKU2,    COL_CYOKU3,
					COL_HOKA1,    COL_HOKA2,     COL_HOKA3,     COL_HOKA4,     COL_HOKA5,
					COL_TATIMES,  COL_SNRIYUU,   COL_UPDTTIMES, UPDATE_DATE,   UPDATE_USER
			};
			this.setPreparedStatementWithProperties(PreparedStatement.Mode.UPDATE, properties);
			this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
			this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.EQUAL);
			
			prepareStatement(sb.toString());
			setParam(index++, dto.getTaJikoku());
			setParam(index++, dto.getKinmuJi());
			setParam(index++, dto.getKyukeiJi());
			setParam(index++, dto.getTHankyuKb());
			setParam(index++, dto.getSoRiyuu());
			setParam(index++, dto.getSoComent());
			setParam(index++, dto.getSoSyoumei());
			setParam(index++, dto.getSoJikan());
			setParam(index++, dto.getZaJikan());
			setParam(index++, dto.getKsJikan());
			setParam(index++, dto.getSnJikan());
			setParam(index++, dto.getSyokuji());
			setParam(index++, dto.getCyoku1());
			setParam(index++, dto.getCyoku2());
			setParam(index++, dto.getCyoku3());
			setParam(index++, dto.getHoka1());
			setParam(index++, dto.getHoka2());
			setParam(index++, dto.getHoka3());
			setParam(index++, dto.getHoka4());
			setParam(index++, dto.getHoka5());
			setParam(index++, dto.getTaTimes());
			setParam(index++, dto.getSnRiyuu());
			setParam(index++, dto.getUpdtTimes());
			setCommonParams(false);
			// L[
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			executeUpdate();
			chkUpdate(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^XVixɓ́j
	 * @param dto XVΏDTO
	 * @return int XV()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int updateHoliday(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			StringBuffer sb = new StringBuffer();
			sb.append("UPDATE ");
			sb.append(TABLE);
			sb.append(" SET ");
			sb.append(COL_KKRIYUU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_DAIKYUJYU + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKCOMENT + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKSYOUMEI + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKJIKAN + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_KKTIMES + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(COL_UPDTTIMES + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_DATE + " =?" + MospConst.DATA_SEPARATOR);
			sb.append(UPDATE_USER + " =?");
			sb.append(" WHERE ");
			sb.append(COL_KCODE + " =?");
			sb.append(" AND ");
			sb.append(COL_HIZUKE + " =?");
			
			// GAE
			String properties[] = {
					COL_KKRIYUU, COL_DAIKYUJYU, COL_KKCOMENT, COL_KKSYOUMEI, COL_KKJIKAN,
					COL_KKTIMES, COL_UPDTTIMES, UPDATE_DATE,  UPDATE_USER
			};
			this.setPreparedStatementWithProperties(PreparedStatement.Mode.UPDATE, properties);
			this.pob.appendWhere(COL_KCODE, Query.FilterOperator.EQUAL);
			this.pob.appendWhere(COL_HIZUKE, Query.FilterOperator.EQUAL);
			
			prepareStatement(sb.toString());
			setParam(index++, dto.getKKRiyuu());
			setParam(index++, dto.getDaiKyuJyu());
			setParam(index++, dto.getKKComent());
			setParam(index++, dto.getKKSyoumei());
			setParam(index++, dto.getKKJikan());
			setParam(index++, dto.getKKTimes());
			setParam(index++, dto.getUpdtTimes());
			setCommonParams(false);
			// L[
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			executeUpdate();
			chkUpdate(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^XV
	 * @param dto XVΏDTO
	 * @return int XV()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int update(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			prepareStatement(getUpdateQuery(getClass()));
			setParams(dto, false);
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			executeUpdate();
			chkUpdate(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * f[^폜
	 * @param dto XVΏDTO
	 * @return int 폜()
	 * @throws SQLException SQLOꍇ
	 * @throws IllegalAccessException	\bhɃANZXłȂꍇ
	 * @throws NoSuchFieldException	tB[hȂꍇ
	 * @throws MospException 	MosPOꍇ
	 */
	public int delete(MSyukkinboDto dto) throws SQLException, IllegalAccessException, NoSuchFieldException,
			MospException {
		try {
			index = 1;
			prepareStatement(getDeleteQuery(getClass()));
			setParam(index++, dto.getKCode());
			setParam(index++, dto.getHizuke());
			executeUpdate();
			chkDelete(1);
			return cnt;
		} catch (SQLException e) {
			throw e;
		} finally {
			releaseResultSet();
			releasePreparedStatement();
		}
	}
	
	/**
	 * p[^ݒ
	 * @param dto XVΏDTO
	 * @param isInsert  }tO(trueF}AfalseFXV)
	 * @throws SQLException SQLOꍇ
	 */
	private void setParams(MSyukkinboDto dto, boolean isInsert) throws SQLException {
		setParam(index++, dto.getKCode()); //ЈR[h
		setParam(index++, dto.getHizuke()); //t
		setParam(index++, dto.getNen()); //N
		setParam(index++, dto.getTuki()); //
		setParam(index++, dto.getHi()); //
		setParam(index++, dto.getSyozoku()); //R[h
		setParam(index++, dto.getNinsyo()); //F؎
		setParam(index++, dto.getSyJikoku()); //oΎ
		setParam(index++, dto.getKinmu()); //Ζ`
		setParam(index++, dto.getSHankyuKb()); //x敪
		setParam(index++, dto.getKyusyuKb()); //xo敪
		setParam(index++, dto.getTiRiyuu()); //xR
		setParam(index++, dto.getTiComent()); //xRg
		setParam(index++, dto.getTiSyoumei()); //xؖ
		setParam(index++, dto.getTiJikan()); //x
		setParam(index++, dto.getSyTimes()); //oΓ͓
		setParam(index++, dto.getTaJikoku()); //ގЎ
		setParam(index++, dto.getKinmuJi()); //Ζ
		setParam(index++, dto.getKyukeiJi()); //xe
		setParam(index++, dto.getTHankyuKb()); //x敪
		setParam(index++, dto.getSoRiyuu()); //ޗR
		setParam(index++, dto.getSoComent()); //ރRg
		setParam(index++, dto.getSoSyoumei()); //ޏؖ
		setParam(index++, dto.getSoJikan()); //ގ
		setParam(index++, dto.getZaJikan()); //cƎ
		setParam(index++, dto.getKsJikan()); //xo
		setParam(index++, dto.getSnJikan()); //[鎞
		setParam(index++, dto.getSyokuji()); //H蓖x
		setParam(index++, dto.getCyoku1()); //1蓖x
		setParam(index++, dto.getCyoku2()); //2蓖x
		setParam(index++, dto.getCyoku3()); //3蓖x
		setParam(index++, dto.getHoka1()); //̑x1
		setParam(index++, dto.getHoka2()); //̑x2
		setParam(index++, dto.getHoka3()); //̑x3
		setParam(index++, dto.getHoka4()); //̑x4
		setParam(index++, dto.getHoka5()); //̑x5
		setParam(index++, dto.getTaTimes()); //ގГ͓
		setParam(index++, dto.getKKRiyuu()); //xɗR
		setParam(index++, dto.getDaiKyuJyu()); //x[
		setParam(index++, dto.getKKComent()); //xɃRg
		setParam(index++, dto.getKKSyoumei()); //xɏؖ
		setParam(index++, dto.getKKJikan()); //xɎ
		setParam(index++, dto.getKKTimes()); //xɓ͓
		setParam(index++, dto.getSnRiyuu()); //FR
		setParam(index++, dto.getSnComent()); //FRg
		setParam(index++, dto.getSnTimes()); //F͓
		setParam(index++, dto.getUpdtTimes()); //XV
		setParam(index++, dto.getNijiKyu()); //񎞊ԔNx
		setParam(index++, dto.getWarimasi1()); //1.00
		setParam(index++, dto.getZKinmu()); //OΖ`
		setCommonParams(isInsert);
	}
	
}
